cmoncrawl.aggregator.gateway\_query
===================================

.. automodule:: cmoncrawl.aggregator.gateway_query

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autoclass:: GatewayAggregator
      :members:

   
   
   



